/*******************************************************************************
* udora.c                                                       by Ken Kirksey *
* Version 1.0b1                                                    20 Sep 1992 *
*                                                                              *
* This program takes the Out file generated by Eudora and automatically parses *
* out and mails each message in the file.  Consult the Readme file that came   *
* with this source file for complete details on it's use.                      *
*                                                                              *
* Eudora )1990 by the University of Illinois Board of Trustees.                *
* Eudora was written by Steve Dorner                                           *
*                                                                              *
* This program )1992 Ken Kirksey.  It may be modified for your personal use    *
* only.  Do not distribute an modified versions of this program.               *
*******************************************************************************/
#include <stdio.h>
#include <string.h>

#ifdef THINKC
#include <console.h>
#endif

/*=============================================================================+
|                           Macros and Constants                               |
+=============================================================================*/
#define MAIL_TEMP_FILE  "udora.tmp"
#define SIG_FILE        ".signature"
#define TRUE            1
#define FALSE           0

/*=============================================================================+
|                                Variables                                     |
+=============================================================================*/
FILE    *infile,
        *outfile,
        *sigfile;
    
char    buffer1 [120],
        *charPtr,
        toAddress[120],
        subject[180];
        
int     isSigfile;
        

/*=============================================================================+
|                                  MAIN                                        |
+=============================================================================*/
main (argc, argv)
int argc;
char **argv;
{

#ifdef THINKC
    argc = ccommand (&argv);
#endif
    
    /*-------------------------------------------------------------------------+
    | Report error if they didn't give a mail file name.                       |
    +-------------------------------------------------------------------------*/
    if (argc < 2)
    {
        fprintf (stderr, "\n Useage: eudora <filename>");
        exit (-1);
    }
    
    /*-------------------------------------------------------------------------+
    | Open input mail file.                                                    |
    +-------------------------------------------------------------------------*/
    if ( (infile = fopen (argv[1], "r")) == NULL)
    {
        perror ("Error opening input file");
        exit (-1);
    }
    
    /*-------------------------------------------------------------------------+
    | Open Temp file.                                                          |
    +-------------------------------------------------------------------------*/
    if ( (outfile = fopen ("eudora.tmp", "w")) == NULL)
    {
        perror ("Error opening udora temp file");
        exit (-1);
    }
    
    /*-------------------------------------------------------------------------+
    | Check for the existence of the signature file.                           |
    +-------------------------------------------------------------------------*/
    if ( (sigfile = fopen (SIG_FILE, "r")) == NULL)
        isSigfile = FALSE;
    else
        isSigfile = TRUE;
    
    fclose (sigfile);
    
    
    /*-------------------------------------------------------------------------+
    | Priming read.  Read in destination address from mail header.             |
    +-------------------------------------------------------------------------*/
    fgets (buffer1, 119, infile);
    fgets (buffer1, 119, infile);
    strcpy ( toAddress, (buffer1+4));

    /*-------------------------------------------------------------------------+
    | Handle addresses of the form "username@domain (Real Name)"               |
    +-------------------------------------------------------------------------*/
    if (  (charPtr = strchr (toAddress, '(')) != NULL) 
        *charPtr = '\0';

    /*-------------------------------------------------------------------------+
    | Handle addresses of the form "Real Name <username@domain>"               |
    +-------------------------------------------------------------------------*/
    else if (  (charPtr = strchr (toAddress, '<')) != NULL)
    {
        strcpy (toAddress, (charPtr+1));
        charPtr = strchr (toAddress, '>');
        *charPtr = '\0';
    }
    /*-------------------------------------------------------------------------+
    | Handle a plain-jane normal type address.                                 |
    +-------------------------------------------------------------------------*/
    else
        *(toAddress + strlen (toAddress)-1) = '\0';

    /*-------------------------------------------------------------------------+
    | Read in subject and eat the rest of the header lines.                    |
    +-------------------------------------------------------------------------*/
    fgets (buffer1, 119, infile);
    fgets (buffer1, 119, infile);
    strcpy ( subject, (buffer1+9) );
    *(subject + strlen (subject)-1) = '\0';
    fgets (buffer1, 119, infile);
    fgets (buffer1, 119, infile);
    fgets (buffer1, 119, infile);
    fgets (buffer1, 119, infile);
    
    /*-------------------------------------------------------------------------+
    | Main Loop Time!  We read in each message until we hit the header of the  |
    | following message.  Then we mail the message.                            |
    +-------------------------------------------------------------------------*/
    while (!feof (infile))
    {
        /*---------------------------------------------------------------------+
        | If the line starts with "From:" then we've hit the header of the     |
        | next message.                                                        |
        +---------------------------------------------------------------------*/
        if ( (buffer1[0] == 'F') && (buffer1[1] == 'r') &&
             (buffer1[2] == 'o') && (buffer1[3] == 'm') )
        {
            /*-----------------------------------------------------------------+
            | Close the temp file.  Mail the current message and post a status |
            | report to stdout.                                                |
            +-----------------------------------------------------------------*/
            fclose (outfile);
                
            sprintf (buffer1, "mailing \"%s\" to %s", subject, toAddress);
            fprintf (stdout, "%s\n", buffer1);

            sprintf (buffer1, "mail -s \"%s\" %s < eudora.tmp", subject,
                         toAddress);
            system (buffer1);
                         
            /*-----------------------------------------------------------------+
            | Remove the temp file, create a new one and open it.              |
            +-----------------------------------------------------------------*/
            remove ("eudora.tmp");
                
            if ( (outfile = fopen ("eudora.tmp", "w")) == NULL)
            {
                perror ("Error opening output file");
                exit (-1);
            }
                
            /*-----------------------------------------------------------------+
            | Read in address.                                                 |
            +-----------------------------------------------------------------*/
            fgets (buffer1, 119, infile);
            strcpy ( toAddress, (buffer1+4));

            /*-----------------------------------------------------------------+
            | Handle addresses of the form "username@domain (Real Name)"       |
            +-----------------------------------------------------------------*/
            if (  (charPtr = strchr (toAddress, '(')) != NULL) 
                *charPtr = '\0';

            /*-----------------------------------------------------------------+
            | Handle addresses of the form "Real Name <username@domain>"       |
            +-----------------------------------------------------------------*/
            else if (  (charPtr = strchr (toAddress, '<')) != NULL)
            {
                strcpy (toAddress, (charPtr+1));
                charPtr = strchr (toAddress, '>');
                *charPtr = '\0';
            }
            /*-----------------------------------------------------------------+
            | Handle a plain-jane normal type address.                         |
            +-----------------------------------------------------------------*/
            else
                *(toAddress + strlen (toAddress)-1) = '\0';
                
            /*-----------------------------------------------------------------+
            | Read in Subject and eat rest of mail header lines.               |
            +-----------------------------------------------------------------*/
            fgets (buffer1, 119, infile);
            fgets (buffer1, 119, infile);
                
            strcpy ( subject, (buffer1+9) );
            *(subject + strlen (subject)-1) = '\0';
            fgets (buffer1, 119, infile);
            fgets (buffer1, 119, infile);
            fgets (buffer1, 119, infile);
                
        }

        /*---------------------------------------------------------------------+
        | If the line starts with "~s", then we insert the signature here.     |
        +---------------------------------------------------------------------*/
        else if ( (buffer1[0] == '~') && (buffer1[1] == 's') )
        {
            if (isSigfile)
            {
                if ( (sigfile = fopen (SIG_FILE, "r")) == NULL)
                {
                    perror ("Error opening signature file");
                    exit (-1);
                }
                
                fgets (buffer1, 119, sigfile);
                while (!feof (sigfile))
                {
                    fputs (buffer1, outfile);
                    fgets (buffer1, 119, sigfile);
                }
                fclose (sigfile);
            }
        }
    
        /*---------------------------------------------------------------------+
        | This is just a line in the mail message. Write it to the temp file.  |
        +---------------------------------------------------------------------*/
        else
            fprintf (outfile, "%s", buffer1);
            
        fgets (buffer1, 119, infile);
        
    }
    
    /*-------------------------------------------------------------------------+
    | We've reache the end of the mail file.  Close it and mail the last       |
    | message.                                                                 |
    +-------------------------------------------------------------------------*/
    fclose (outfile);
    sprintf (buffer1, "mailing \"%s\" to %s", subject, toAddress);
    fprintf (stdout, "%s\n", buffer1);

    sprintf (buffer1, "mail -s \"%s\" %s < eudora.tmp", subject, toAddress);
    system (buffer1);
    
    remove ("eudora.tmp");
    
}
